+++
title = "Issue 336"
tags = ["issues"]
draft = false
+++

`ox-hugo` Issue
\#[336](https://github.com/kaushalmodi/ox-hugo/issues/336)

This issue only appears when there is a citation Giovanelli (2016)

[Tag]({{< relref "root-level-content-empty-section" >}})

[Exclude tag]({{< relref "336_test" >}})

## References {#references}

<div id="refs" class="references hanging-indent">
  <div></div>


<div id="ref-giovanelli2016">
  <div></div>

Giovanelli, Marco. 2016. "\"\...But I Still Can't Get Rid of a Sense of
Artificiality\" the Reichenbach--Einstein Debate on the Geometrization
of the Electromagnetic Field." *Studies in History and Philosophy of
Science* 54: 35--51.

</div>

</div>
